# Vaccination Project

This project is a prototype of IAM within a microservices architecture with quarkus and keycloak.

The prototype does not have microservices implemented at this current time. It only shows a possible way to handle access management.
The current implementation would not be recommended for production.

Please follow the steps below to run the application in the intended way.

This project uses Quarkus, the Supersonic Subatomic Java Framework.

If you want to learn more about Quarkus, please visit its website: https://quarkus.io/ .

## Running the application in dev mode

You can run your application in dev mode that enables live coding using:

```shell script
./mvnw compile quarkus:dev
```

> **_NOTE:_**  Quarkus now ships with a Dev UI, which is available in dev mode only at http://localhost:8080/q/dev/.

## Packaging and running the application

The application can be packaged using:

```shell script
./mvnw package
```

It produces the `quarkus-run.jar` file in the `target/quarkus-app/` directory.
Be aware that it’s not an _über-jar_ as the dependencies are copied into the `target/quarkus-app/lib/` directory.

The application is now runnable using `java -jar target/quarkus-app/quarkus-run.jar`.

If you want to build an _über-jar_, execute the following command:

```shell script
./mvnw package -Dquarkus.package.type=uber-jar
```

The application, packaged as an _über-jar_, is now runnable using `java -jar target/*-runner.jar`.

## Running Keycloak Dev
Keycloak can be started with the following command:
```shell script
docker run -p 8180:8080 -e KEYCLOAK_ADMIN=admin -e KEYCLOAK_ADMIN_PASSWORD=admin quay.io/keycloak/keycloak:19.0.2 start-dev
```
> **_NOTE:_**  Keycloak should not be run in dev mode when used for production environments.

> **_NOTE:_**  When not using a database the flag "-v" can be used to set a volume for persistent storage.

## Creating Keycloak realm
When Keycloak is running you can access the admin console via the following link http://localhost:8180/admin/master/console

> **_NOTE:_**  The credentials for logging in to the admin console are both "admin"

Here you can create a new realm which will contain your oauth provider

![Screenshot](./images/realms.png)

Import the realm-export.json file to create the realm

![Screenshot](./images/realmCreate.png)

## Creating Keycloak users
The realm is now created, now you need to create some users who will be able to access certain endpoints.

Go to the users tab within the newly created realm. Here you will be able to create new users.

![Screenshot](./images/userCreate.png)

Next assign a role to the user

> **_NOTE:_** The roles made for this project are: patient, arts, prikker, helpdesk and ggdmedewerker

![Screenshot](./images/userRole.png)

Lastly give the newly created user some credentials which you will use to get access to the endpoints.

![Screenshot](./images/userCredentials.png)

## Getting an access token
Now that both the application and Keycloak are running you can use your newly created user to get an access token.

To get an access token you will need to make a request which can be done with the following command.

```shell script
curl --insecure -X POST http://localhost:8180/realms/vaccinatieregister/protocol/openid-connect/token \
    --user backend-service:secret \
    -H 'content-type: application/x-www-form-urlencoded' \
    -d 'username=(YOURUSERNAME)&password=(YOURPASSWORD)&grant_type=password'
```
> **_NOTE:_** You will need to fill in your users username and password on places of "YOURUSERNAME" and "YOURPASSWORD". 
> Do not forget to remove the parentheses.

Copy the access token that is given to you.
> **_NOTE:_** The access token will only be active for 5 minutes. (This can be changed in Keycloak)

## Communicating with endpoints
Now that you have received your access tokens you can communicate with the endpoint to which the users role/roles has/have access to.
> **_NOTE:_**  At the end of this section there is a list with all endpoints and the roles that have access to it.

Now an example will be given for how to communicate with the endpoints
```shell script
curl -v -X GET \
  http://localhost:8080/api/afspraak \
  -H "Authorization: Bearer "$access_token
```

> **_NOTE:_**  $access_token will need to be replaced/filled with your access token


| Endpoint                     | Roles                                           |
|------------------------------|-------------------------------------------------|
| GET /api/afspraak            | helpdesk                                        |
| GET /api/afspraak/{id}       | patient, helpdesk,ggdmedewerker                 |
| CREATE /api/afspraak         | helpdesk, ggdmedewerker                         |
| PATCH /api/afspraak/{id}     | helpdesk, ggdmedewerker                         |
| DELETE /api/afspraak/{id}    | helpdesk, ggdmedewerker                         |
|                              |                                                 |
| GET /api/arts                | arts                                            |
| GET /api/arts/{id}           | arts                                            |
| CREATE /api/arts             | arts                                            |
| PATCH /api/arts/{id}         | arts                                            |
| DELETE /api/arts/{id}        | arts                                            |
|                              |                                                 |
| GET /api/dossier             | arts                                            |
| GET /api/dossier/{id}        | patient, arts                                   |
| CREATE /api/dossier          | arts                                            |
| PATCH /api/dossier/{id}      | arts                                            |
| DELETE /api/dossier/{id}     | arts                                            |                         |              |
|                              |                                                 |
| GET /api/medewerker          | ggdmedewerker                                   |
| GET /api/medewerker/{id}     | ggdmedewerker                                   |
| CREATE /api/medewerker       | ggdmedewerker                                   |
| PATCH /api/medewerker/{id}   | ggdmedewerker                                   |
| DELETE /api/medewerker/{id}  | ggdmedewerker                                   |
|                              |                                                 |
| GET /api/patient             | arts                                            |
| GET /api/patient/{id}        | patient, arts, helpdesk                         |
| CREATE /api/patient          | arts                                            |
| PATCH /api/patient/{id}      | arts                                            |
| DELETE /api/patient/{id}     | arts                                            |
|                              |                                                 |
| GET /api/prikLocatie         | arts, helpdesk, ggdmedewerker                   |
| GET /api/prikLocatie/{id}    | arts, helpdesk, ggdmedewerker                   |
| CREATE /api/prikLocatie      | ggdmedewerker                                   |
| PATCH /api/prikLocatie/{id}  | ggdmedewerker                                   |
| DELETE /api/prikLocatie/{id} | ggdmedewerker                                   |
|                              |                                                 |
| GET /api/prikker             | arts, prikker                                   |
| GET /api/prikker/{id}        | arts, helpdesk, prikker                         |
| CREATE /api/prikker          | arts                                            |
| PATCH /api/prikker/{id}      | arts                                            |
| DELETE /api/prikker/{id}     | arts                                            |
|                              |                                                 |
| GET /api/vaccinatie          | patient, arts, helpdesk, ggdmedewerker          |
| GET /api/vaccinatie/{id}     | patient, arts, helpdesk, ggdmedewerker          |
| CREATE /api/vaccinatie       | arts, ggdmedewerker                             |
| PATCH /api/vaccinatie/{id}   | arts, ggdmedewerker                             |
| DELETE /api/vaccinatie/{id}  | arts, ggdmedewerker                             |
|                              |                                                 |
| GET /api/vaccine             | patient, arts, helpdesk, ggdmedewerker, prikker |
| GET /api/vaccine/{id}        | patient, arts, helpdesk, ggdmedewerker, prikker |
| CREATE /api/vaccine          | ggdmedewerker                                   |
| PATCH /api/vaccine/{id}      | ggdmedewerker                                   |
| DELETE /api/vaccine/{id}     | ggdmedewerker                                   |

## Related Guides

- RESTEasy Classic ([guide](https://quarkus.io/guides/resteasy)): REST endpoint framework implementing JAX-RS and more

## Provided Code

### RESTEasy JAX-RS

Easily start your RESTful Web Services

[Related guide section...](https://quarkus.io/guides/getting-started#the-jax-rs-resources)
