package com.example.rest;

import com.example.bo.Afspraak;
import com.example.bo.Patient;
import com.example.bo.Prikker;
import com.example.bo.Vaccin;
import com.example.db.AfspraakRepository;
import org.eclipse.microprofile.openapi.annotations.Operation;
import org.eclipse.microprofile.openapi.annotations.responses.APIResponse;

import javax.annotation.security.RolesAllowed;
import javax.inject.Inject;
import javax.ws.rs.*;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.Response;
import java.util.ArrayList;

@Path("/afspraak")
public class AfspraakResource {
    @Inject
    AfspraakRepository afspraakRepository;

    @GET
    @Path("{id}")
    @RolesAllowed({"patient","helpdesk","ggdmedewerker"})
    @Operation(summary = "", description = "Haal een afspraak op")
    @Produces(MediaType.APPLICATION_JSON)
    @APIResponse(
            responseCode = "200",
            description = "All OK")

    @APIResponse(
            responseCode = "204",
            description = "geen afspraak gevonden" )

    public Response getAfspraak (@PathParam("id") String id) {
        Afspraak afspraak = null;
        try {
            afspraak = afspraakRepository.find(id);
        } catch (Exception e) {
            //
        }
        if (afspraak != null) {
            //OK
            return Response.ok(afspraak).build();
        } else {
            //
            return Response.noContent().build();
        }
    }

    @GET
    @RolesAllowed("helpdesk")
    @Operation(summary = "", description = "Haal een lijst van alle afspraken op")
    @Produces(MediaType.APPLICATION_JSON)
    public ArrayList<Afspraak> getAfspraak () {
        //
        return afspraakRepository.getAll();
    }

    @POST
    @RolesAllowed({"helpdesk","ggdmedewerker"})
    @Operation(description = "voeg een afspraak toe")
    public Afspraak addAfspraak( Afspraak afspraak ) {

        return afspraakRepository.voegToe(afspraak);

    }

    @DELETE
    @Path("{id}")
    @RolesAllowed({"helpdesk","ggdmedewerker"})
    @Operation(description = "verwijder een afspraak")
    public boolean removeAfspraak(@PathParam("id") String id){
        Afspraak afspraak = null;
        try {
            afspraak = afspraakRepository.find(id);
        } catch (Exception e) {
            //
        }
        if (afspraak != null) {
            //OK
            afspraakRepository.Remove(id);
            return true;
        } else {
            //
            return false;
        }
    }

    @PATCH
    @Path("{id}")
    @RolesAllowed({"helpdesk","ggdmedewerker"})
    @Operation(description = "wijzig een afspraak")
    public Response modifyAfspraak(Afspraak afspraak){
        Afspraak RepoAfspraak = null;
        try {
            RepoAfspraak = afspraakRepository.find(afspraak.getId());
        } catch (Exception e) {
            //
        }

        if (RepoAfspraak != null){
            afspraakRepository.Edit(afspraak);
            return Response.ok(afspraak).build();
        }
        else {
            return Response.noContent().build();
        }
    }

}
