package com.example.rest;

import com.example.bo.Arts;
import com.example.db.ArtsRepository;
import org.eclipse.microprofile.openapi.annotations.Operation;
import org.eclipse.microprofile.openapi.annotations.responses.APIResponse;

import javax.annotation.security.RolesAllowed;
import javax.inject.Inject;
import javax.ws.rs.*;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.Response;
import java.util.ArrayList;

@Path("/arts")
public class ArtsResource {
    @Inject
    ArtsRepository artsRepository;

    @GET
    @Path("{id}")
    @RolesAllowed("arts")
    @Operation(summary = "", description = "Haal de informatie van een arts op")
    @Produces(MediaType.APPLICATION_JSON)
    @APIResponse(
            responseCode = "200",
            description = "All OK")

    @APIResponse(
            responseCode = "204",
            description = "geen informatie gevonden")

    public Response getArts(@PathParam("id") String id) {
        Arts arts = null;
        try {
            arts = artsRepository.find(id);
        } catch (Exception e) {
            //
        }
        if (arts != null) {
            //OK
            return Response.ok(arts).build();
        } else {
            //
            return Response.noContent().build();
        }
    }

    @GET
    @RolesAllowed("arts")
    @Operation(summary = "", description = "Haal een lisjt met alle artsen op")
    @Produces(MediaType.APPLICATION_JSON)
    public ArrayList<Arts> getArts() {
        //
        return artsRepository.getAll();
    }

    @POST
    @RolesAllowed("arts")
    @Operation(description = "add a arts")
    public Arts addArts(Arts arts) {

        return artsRepository.voegToe(arts);

    }

    @DELETE
    @Path("{id}")
    @RolesAllowed("arts")
    @Operation(description = "verwijder de informatie over een arts")
    public boolean removeArts(@PathParam("id") String id) {
        Arts arts = null;
        try {
            arts = artsRepository.find(id);
        } catch (Exception e) {
            //
        }
        if (arts != null) {
            //OK
            artsRepository.Remove(id);
            return true;
        } else {
            //
            return false;
        }
    }

    @PATCH
    @Path("{id}")
    @RolesAllowed("arts")
    @Operation(description = "wijzig de informatie over een arts")
    public Response modifyArts(Arts arts) {
        Arts RepoArts = null;
        try {
            RepoArts = artsRepository.find(arts.getId());
        } catch (Exception e) {
            //
        }

        if (RepoArts != null) {
            artsRepository.Edit(arts);
            return Response.ok(arts).build();
        } else {
            return Response.noContent().build();
        }
    }
}

