package com.example.rest;

import com.example.bo.Dossier;
import com.example.db.DossierRepository;
import org.eclipse.microprofile.openapi.annotations.Operation;
import org.eclipse.microprofile.openapi.annotations.responses.APIResponse;

import javax.annotation.security.RolesAllowed;
import javax.inject.Inject;
import javax.ws.rs.*;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.Response;
import java.util.ArrayList;

@Path("/dossier")
public class DossierResource {

    @Inject
    DossierRepository dossierRepository;

    @GET
    @Path("{id}")
    @RolesAllowed({"arts","patient"})
    @Operation(summary = "", description = "Haal een specifiek dossier op")
    @Produces(MediaType.APPLICATION_JSON)
    @APIResponse(
            responseCode = "200",
            description = "All OK")

    @APIResponse(
            responseCode = "204",
            description = "Geen dossier gevonden")

    public Response getDossier(@PathParam("id") String id) {
        Dossier dossier = null;
        try {
            dossier = dossierRepository.find(id);
        } catch (Exception e) {
            //
        }
        if (dossier != null) {
            //OK
            return Response.ok(dossier).build();
        } else {
            //
            return Response.noContent().build();
        }
    }

    @GET
    @RolesAllowed("arts")
    @Operation(summary = "", description = "Haal een lijst van dossiers op")
    @Produces(MediaType.APPLICATION_JSON)
    public ArrayList<Dossier> getDossier() {
        //
        return dossierRepository.getAll();
    }

    @POST
    @RolesAllowed("arts")
    @Operation(description = "Voeg een nieuw dossier toe")
    public Dossier addDossier(Dossier dossier) {

        return dossierRepository.voegToe(dossier);

    }

    @DELETE
    @Path("{id}")
    @RolesAllowed("arts")
    @Operation(description = "verwijder een dossier")
    public boolean removeDossier(@PathParam("id") String id) {
        Dossier dossier = null;
        try {
            dossier = dossierRepository.find(id);
        } catch (Exception e) {
            //
        }
        if (dossier != null) {
            //OK
            dossierRepository.Remove(id);
            return true;
        } else {
            //
            return false;
        }
    }

    @PATCH
    @Path("{id}")
    @RolesAllowed("arts")
    @Operation(description = "Pas een dossier aan")
    public Response modifyDossier(Dossier dossier) {
        Dossier RepoDossier = null;
        try {
            RepoDossier = dossierRepository.find(dossier.getId());
        } catch (Exception e) {
            //
        }

        if (RepoDossier != null) {
            dossierRepository.Edit(dossier);
            return Response.ok(dossier).build();
        } else {
            return Response.noContent().build();
        }
    }
}
