package com.example.rest;

import com.example.bo.Medewerker;
import com.example.db.MedewerkerRepository;
import org.eclipse.microprofile.openapi.annotations.Operation;
import org.eclipse.microprofile.openapi.annotations.responses.APIResponse;

import javax.annotation.security.RolesAllowed;
import javax.inject.Inject;
import javax.ws.rs.*;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.Response;
import java.util.ArrayList;

@Path("/medewerker")
public class MedewerkerResource {
    @Inject
    MedewerkerRepository medewerkerRepository;

    @GET
    @Path("{id}")
    @RolesAllowed("ggdmedewerker")
    @Operation(summary = "", description = "Haal de informatie van een specifieke medewerker op")
    @Produces(MediaType.APPLICATION_JSON)
    @APIResponse(
            responseCode = "200",
            description = "All OK")

    @APIResponse(
            responseCode = "204",
            description = "Geen medewerker gevonden")

    public Response getMedewerker(@PathParam("id") String id) {
        Medewerker medewerker = null;
        try {
            medewerker = medewerkerRepository.find(id);
        } catch (Exception e) {
            //
        }
        if (medewerker != null) {
            //OK
            return Response.ok(medewerker).build();
        } else {
            //
            return Response.noContent().build();
        }
    }

    @GET
    @RolesAllowed("ggdmedewerker")
    @Operation(summary = "", description = "Haal een lijst van ggd-medewerkers op")
    @Produces(MediaType.APPLICATION_JSON)
    public ArrayList<Medewerker> getMedewerker() {
        //
        return medewerkerRepository.getAll();
    }

    @POST
    @RolesAllowed("ggdmedewerker")
    @Operation(description = "voeg een ggd-medewerker toe")
    public Medewerker addMedewerker(Medewerker medewerker) {

        return medewerkerRepository.voegToe(medewerker);

    }

    @DELETE
    @Path("{id}")
    @RolesAllowed("ggdmedewerker")
    @Operation(description = "verwijder de informatie van een ggd-medewerker")
    public boolean removeMedewerker(@PathParam("id") String id) {
        Medewerker medewerker = null;
        try {
            medewerker = medewerkerRepository.find(id);
        } catch (Exception e) {
            //
        }
        if (medewerker != null) {
            //OK
            medewerkerRepository.Remove(id);
            return true;
        } else {
            //
            return false;
        }
    }

    @PATCH
    @Path("{id}")
    @RolesAllowed("ggdmedewerker")
    @Operation(description = "wijzig de informatie van een ggd-medewerker")
    public Response modifyMedewerker(Medewerker medewerker) {
        Medewerker RepoMedewerker = null;
        try {
            RepoMedewerker = medewerkerRepository.find(medewerker.getId());
        } catch (Exception e) {
            //
        }

        if (RepoMedewerker != null) {
            medewerkerRepository.Edit(medewerker);
            return Response.ok(medewerker).build();
        } else {
            return Response.noContent().build();
        }
    }
}
