package com.example.rest;



import java.util.ArrayList;
import javax.annotation.security.RolesAllowed;
import javax.inject.Inject;
import javax.ws.rs.*;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.Response;


import com.example.bo.Patient;
import com.example.db.PatientRepository;

import org.eclipse.microprofile.openapi.annotations.Operation;
import org.eclipse.microprofile.openapi.annotations.media.Content;
import org.eclipse.microprofile.openapi.annotations.responses.APIResponse;

@Path("/patient")
public class PatientResource {
    @Inject
    PatientRepository patientRepository;

    @GET
    @Path("{BSNnummer}")
    @RolesAllowed({"arts","patient","helpdesk"})
    @Operation(summary = "", description = "Haal de informatie van een patient op")
    @Produces(MediaType.APPLICATION_JSON)
    @APIResponse(
            responseCode = "200",
            description = "All OK")

    @APIResponse(
            responseCode = "204",
            description = "Geen patient gevonden" )

    public Response getPatient (@PathParam("BSNnummer") String BSNnummer) {
        Patient patient = null;
        try {
            patient = patientRepository.find(BSNnummer);
        } catch (Exception e) {
            //
        }
        if (patient != null) {
            //OK
            return Response.ok(patient).build();
        } else {
            //
            return Response.noContent().build();
        }
    }

    @GET
    @RolesAllowed("arts")
    @Operation(summary = "", description = "Haal een lijst van patienten op")
    @Produces(MediaType.APPLICATION_JSON)
    public ArrayList<Patient> getPatient() {
        //
        return patientRepository.getAll();
    }

    @POST
    @RolesAllowed("arts")
    @Operation(description = "Voeg een patient toe")
    public Patient addPatient( Patient patient) {
        //voeg patient toe aan lijst van patienten

        return patientRepository.voegToe(patient);


    }

    @DELETE
    @Path("{BSNnummer}")
    @RolesAllowed("arts")
    @Operation(description = "Verwijder de informatie over een patient")
    public boolean removePatient(@PathParam("BSNnummer") String BSNnummer){
        Patient patient = null;
        try {
            patient = patientRepository.find(BSNnummer);
        } catch (Exception e) {
            //
        }
        if (patient != null) {
            //OK
            patientRepository.Remove(BSNnummer);
            return true;
        } else {
            //
            return false;
        }

    }

    @PATCH
    @RolesAllowed("arts")
    @Operation(description = "Pas patient informatie aan")
    @APIResponse(
            responseCode = "200",
            description = "All OK")

    @APIResponse(
            responseCode = "204",
            description = "No patient found" )

    public Response modifyPatient(Patient patient){
        Patient RepoPatient = null;
        try {
            RepoPatient = patientRepository.find(patient.getBsnNummer());
        } catch (Exception e) {
            //
        }

        if (RepoPatient != null){
            patientRepository.Edit(patient);
            return Response.ok(patient).build();
        }
        else {
            return Response.noContent().build();
        }
    }
}
