package com.example.rest;

import java.util.ArrayList;
import javax.annotation.security.RolesAllowed;
import javax.inject.Inject;
import javax.ws.rs.*;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.Response;


import com.example.bo.PrikLocatie;
import com.example.db.PrikLocatieRepository;
import org.eclipse.microprofile.openapi.annotations.Operation;
import org.eclipse.microprofile.openapi.annotations.media.Content;
import org.eclipse.microprofile.openapi.annotations.responses.APIResponse;

@Path("/prikLocatie")
public class PrikLocatieResource {
    @Inject
    PrikLocatieRepository prikLocatieRepository;

    @GET
    @Path("{id}")
    @RolesAllowed({"arts","helpdesk","ggdmedewerker"})
    @Operation(summary = "", description = "Haal de informatie van een priklocatie op")
    @Produces(MediaType.APPLICATION_JSON)
    @APIResponse(
            responseCode = "200",
            description = "All OK")

    @APIResponse(
            responseCode = "204",
            description = "Geen priklocatie gevonden" )

    public Response getPrikLocatie(@PathParam("id") String id) {
        PrikLocatie prikLocatie = null;
        try {
            prikLocatie = prikLocatieRepository.find(id);
        } catch (Exception e) {
            //
        }
        if (prikLocatie != null) {
            //OK
            return Response.ok(prikLocatie).build();
        } else {
            //
            return Response.noContent().build();
        }
    }

    @GET
    @RolesAllowed({"arts","helpdesk","ggdmedewerker"})
    @Operation(summary = "", description = "Haal een lijst van priklocaties op")
    @Produces(MediaType.APPLICATION_JSON)
    public ArrayList<PrikLocatie> getPrikLocatie() {
        //
        return prikLocatieRepository.getAll();
    }

    @POST
    @RolesAllowed("ggdmedewerker")
    @Operation(description = "Voeg een priklocatie toe")
    public PrikLocatie addPrikLocatie( PrikLocatie prikLocatie) {
        //voeg prikLocatie toe aan lijst van prikers

        return prikLocatieRepository.voegToe(prikLocatie);


    }

    @DELETE
    @Path("{id}")
    @RolesAllowed("ggdmedewerker")
    @Operation(description = "Verwijder een priklocatie")
    public boolean removePrikLocatie(@PathParam("id") String id){
        PrikLocatie prikLocatie = null;
        try {
            prikLocatie = prikLocatieRepository.find(id);
        } catch (Exception e) {
            //
        }
        if (prikLocatie != null) {
            //OK
            prikLocatieRepository.Remove(id);
            return true;
        } else {
            //
            return false;
        }

    }

    @PATCH
    @RolesAllowed("ggdmedewerker")
    @Operation(description = "Pas een priklocatie aan")
    @APIResponse(
            responseCode = "200",
            description = "All OK")

    @APIResponse(
            responseCode = "204",
            description = "No prikLocatie found" )

    public Response modifyPrikLocatie(PrikLocatie prikLocatie){
        PrikLocatie RepoPrikLocatie = null;
        try {
            RepoPrikLocatie = prikLocatieRepository.find(prikLocatie.getId());
        } catch (Exception e) {
            //
        }

        if (RepoPrikLocatie != null){
            prikLocatieRepository.Edit(prikLocatie);
            return Response.ok(prikLocatie).build();
        }
        else {
            return Response.noContent().build();
        }
    }
}
