package com.example.rest;

import java.util.ArrayList;
import javax.annotation.security.RolesAllowed;
import javax.inject.Inject;
import javax.ws.rs.*;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.Response;


import com.example.bo.Prikker;
import com.example.db.PrikkerRepository;
import org.eclipse.microprofile.openapi.annotations.Operation;
import org.eclipse.microprofile.openapi.annotations.media.Content;
import org.eclipse.microprofile.openapi.annotations.responses.APIResponse;

@Path("/prikker")
public class PrikkerResource {
    @Inject
    PrikkerRepository prikkerRepository;

    @GET
    @Path("{id}")
    @RolesAllowed({"prikker","helpdesk","arts"})
    @Operation(summary = "", description = "Haal de informatie over een prikker op")
    @Produces(MediaType.APPLICATION_JSON)
    @APIResponse(
            responseCode = "200",
            description = "All OK")

    @APIResponse(
            responseCode = "204",
            description = "No prikker found" )

    public Response getPrikker(@PathParam("id") String id) {
        Prikker prikker = null;
        try {
            prikker = prikkerRepository.find(id);
        } catch (Exception e) {
            //
        }
        if (prikker != null) {
            //OK
            return Response.ok(prikker).build();
        } else {
            //
            return Response.noContent().build();
        }
    }

    @GET
    @RolesAllowed({"prikker","arts"})
    @Operation(summary = "", description = "Haal een lijst van prikkers op")
    @Produces(MediaType.APPLICATION_JSON)
    public ArrayList<Prikker> getPrikker() {
        //
        return prikkerRepository.getAll();
    }

    @POST
    @RolesAllowed("arts")
    @Operation(description = "voeg een prikker toe")
    public Prikker addPrikker( Prikker prikker) {
        //voeg prikker toe aan lijst van prikers

        return prikkerRepository.voegToe(prikker);


    }

    @DELETE
    @Path("{id}")
    @RolesAllowed("arts")
    @Operation(description = "Verwijder een prikker")
    public boolean removePrikker(@PathParam("id") String id){
        Prikker prikker = null;
        try {
            prikker = prikkerRepository.find(id);
        } catch (Exception e) {
            //
        }
        if (prikker != null) {
            //OK
            prikkerRepository.Remove(id);
            return true;
        } else {
            //
            return false;
        }

    }

    @PATCH
    @RolesAllowed("arts")
    @Operation(description = "pas een prikker aan")
    @APIResponse(
            responseCode = "200",
            description = "All OK")

    @APIResponse(
            responseCode = "204",
            description = "No prikker found" )

    public Response modifyPrikker(Prikker prikker){
        Prikker RepoPrikker = null;
        try {
            RepoPrikker = prikkerRepository.find(prikker.getId());
        } catch (Exception e) {
            //
        }

        if (RepoPrikker != null){
            prikkerRepository.Edit(prikker);
            return Response.ok(prikker).build();
        }
        else {
            return Response.noContent().build();
        }
    }
}
