package com.example.rest;


import com.example.bo.Vaccinatie;
import com.example.db.VaccinatieRepository;
import org.eclipse.microprofile.openapi.annotations.Operation;
import org.eclipse.microprofile.openapi.annotations.media.Content;
import org.eclipse.microprofile.openapi.annotations.responses.APIResponse;

import javax.annotation.security.DenyAll;
import javax.annotation.security.PermitAll;
import javax.annotation.security.RolesAllowed;
import javax.inject.Inject;
import javax.ws.rs.*;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.Response;
import java.util.ArrayList;

@Path("/vaccinatie")
public class VaccinatieResource {
    @Inject
    VaccinatieRepository vaccinatieRepository;

    @GET
    @Path("{id}")
    @RolesAllowed({"patient","arts","helpdesk","ggdmedewerker"})
    @Operation(summary = "", description = "haal informatie over een gezette vaccinatie op")
    @Produces(MediaType.APPLICATION_JSON)
    @APIResponse(
            responseCode = "200",
            description = "All OK")

    @APIResponse(
            responseCode = "204",
            description = "Geen vaccinatie gevonden" )

    public Response getVaccinatie(@PathParam("id") String id) {
        Vaccinatie vaccinatie = null;
        try {
            vaccinatie = vaccinatieRepository.find(id);
        } catch (Exception e) {
            //
        }
        if (vaccinatie != null) {
            //OK
            return Response.ok(vaccinatie).build();
        } else {
            //
            return Response.noContent().build();
        }
    }

    @GET
    @RolesAllowed({"patient","arts","helpdesk","ggdmedewerker"})
    @Operation(summary = "", description = "Haal een lijst van gezette vaccinaties op")
    @Produces(MediaType.APPLICATION_JSON)
    public ArrayList<Vaccinatie> getVaccinatie() {
        //
        return vaccinatieRepository.getAll();
    }

    @POST
    @RolesAllowed({"arts","ggdmedewerker"})
    @Operation(description = "Voeg een gezette vacinatie toe")
    public Vaccinatie addVaccinatie( Vaccinatie vaccinatie) {
        //voeg vaccinatie toe aan lijst van prikers

        return vaccinatieRepository.voegToe(vaccinatie);


    }

    @DELETE
    @Path("{id}")
    @RolesAllowed({"arts","ggdmedewerker"})
    @Operation(description = "Verwijder een gezette vacinatie")
    public boolean removeVaccinatie(@PathParam("id") String id){
        Vaccinatie vaccinatie = null;
        try {
            vaccinatie = vaccinatieRepository.find(id);
        } catch (Exception e) {
            //
        }
        if (vaccinatie != null) {
            //OK
            vaccinatieRepository.Remove(id);
            return true;
        } else {
            //
            return false;
        }

    }

    @PATCH
    @RolesAllowed({"arts","ggdmedewerker"})
    @Operation(description = "pas een gezette vaccinatie aan")
    @APIResponse(
            responseCode = "200",
            description = "All OK")

    @APIResponse(
            responseCode = "204",
            description = "Geen vaccinatie gevonden" )

    public Response modifyVaccinatie(Vaccinatie vaccinatie){
        Vaccinatie RepoVaccinatie = null;
        try {
            RepoVaccinatie = vaccinatieRepository.find(vaccinatie.getId());
        } catch (Exception e) {
            //
        }

        if (RepoVaccinatie != null){
            vaccinatieRepository.Edit(vaccinatie);
            return Response.ok(vaccinatie).build();
        }
        else {
            return Response.noContent().build();
        }
    }
}
