package com.example.rest;


import com.example.bo.Vaccin;
import com.example.db.VaccineRepository;
import java.util.ArrayList;
import javax.annotation.security.PermitAll;
import javax.annotation.security.RolesAllowed;
import javax.inject.Inject;
import javax.ws.rs.*;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.Response;
import org.eclipse.microprofile.openapi.annotations.Operation;
import org.eclipse.microprofile.openapi.annotations.media.Content;
import org.eclipse.microprofile.openapi.annotations.responses.APIResponse;

@Path("/vaccine")
public class VaccineResource {

    @Inject
    VaccineRepository vaccineRepository;

    @GET
    @Path("{id}")
    @PermitAll
    @Operation(summary = "", description = "Haal informatie over een vaccin op")
    @Produces(MediaType.APPLICATION_JSON)
    @APIResponse(
            responseCode = "200",
            description = "All OK")

    @APIResponse(
            responseCode = "204",
            description = "geen vaccin gevonden" )

    public Response getVaccin (@PathParam("id") String id) {
        Vaccin vaccin = null;
        try {
            vaccin = vaccineRepository.find(id);
        } catch (Exception e) {
            //
        }
        if (vaccin != null) {
            //OK
            return Response.ok(vaccin).build();
        } else {
            //
            return Response.noContent().build();
        }
    }

    @GET
    @PermitAll
    @Operation(summary = "", description = "haal een lijst van vaccins op")
    @Produces(MediaType.APPLICATION_JSON)
    public ArrayList<Vaccin> getVaccin () {
        //
        return vaccineRepository.getAll();
    }

    @POST
    @RolesAllowed("ggdmedewerker")
    @Operation(description = "voeg een vaccin toe")
    public Vaccin addVaccin( Vaccin vaccin) {
        //voeg vaccine toe aan lijst van vaccines

        return vaccineRepository.voegToe(vaccin);


    }

    @DELETE
    @Path("{id}")
    @RolesAllowed("ggdmedewerker")
    @Operation(description = "Verwijder een vaccin")
    public boolean removeVaccin(@PathParam("id") String id){
        Vaccin vaccin = null;
        try {
            vaccin = vaccineRepository.find(id);
        } catch (Exception e) {
            //
        }
        if (vaccin != null) {
            //OK
            vaccineRepository.Remove(id);
            return true;
        } else {
            //
            return false;
        }

    }

    @PATCH
    @RolesAllowed("ggdmedewerker")
    @Operation(description = "pas een vaccin aan")
    @APIResponse(
            responseCode = "200",
            description = "All OK")

    @APIResponse(
            responseCode = "204",
            description = "Geen vaccin gevonden" )

    public Response modifyVaccin(Vaccin vaccin){
        Vaccin RepoVaccin = null;
        try {
            RepoVaccin = vaccineRepository.find(vaccin.getId());
        } catch (Exception e) {
            //
        }

        if (RepoVaccin != null){
            vaccineRepository.Edit(vaccin);
            return Response.ok(vaccin).build();
        }
        else {
            return Response.noContent().build();
        }
    }

}
